@@ -4,7 +4,8 @@ use chopper::chopper::error::ChopperResult;
 use chopper::chopper_cli::ChopperCli;
 use chopper::util::dc_factory::DCFactory;
 
-fn main() -> ChopperResult<()> {
+#[tokio::main]
+async fn main() -> ChopperResult<()> {
     better_panic::Settings::default()
         .verbosity(Verbosity::Full)
         .install();
@@ -12,4 +13,5 @@ fn main() -> ChopperResult<()> {
     ChopperCli::new()
         .with_dc_factory(DCFactory::default())
         .run()
+        .await
 }
